fn replace_html_variable(html: &mut String, name: &str, value: &str)Expand description
Replace the variable with the given name by the given value in the given HTML.
The syntax for a variable is @name@. This is the same format as meson’s
configure_file function.
Logs an error if the variable is not found.